@@ -6,7 +6,6 @@ import nox
 
 nox.options.reuse_existing_virtualenvs = True
 nox.options.sessions = "lint", "tests"
-locations = "src", "tests"
 
 
 @nox.session(python=["3.8", "3.9", "3.10"])
@@ -29,7 +28,7 @@ def lint(session: nox.Session) -> None:
     args = *(session.posargs or ("--show-diff-on-failure",)), "--all-files"
     session.run("pre-commit", "run", *args)
     session.run("python", "-m", "mypy")
-    session.run("python", "-m", "pylint", *locations)
+    session.run("python", "-m", "pylint", "src")
 
 
 @nox.session
